#
# spec file for package libgme
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0
Name:           libgme
Version:        0.6.3
Release:        2.8
Summary:        Collection of video game music file emulators
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://bitbucket.org/mpyne/game-music-emu/wiki/Home
Source0:        https://bitbucket.org/mpyne/game-music-emu/downloads/game-music-emu-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
Game_Music_Emu is a collection of video game music file emulators that support
the following formats and systems:
- AY: ZX Spectrum/Amstrad CPC
- GBS: Nintendo Game Boy
- GYM: Sega Genesis/Mega Drive
- HES: NEC TurboGrafx-16/PC Engine
- KSS: MSX Home Computer/other Z80 systems (doesn't support FM sound)
- NSF/NSFE: Nintendo NES/Famicom (with VRC 6, Namco 106, and FME-7 sound)
- SAP: Atari systems using POKEY sound chip
- SPC: Super Nintendo/Super Famicom
- VGM/VGZ: Sega Master System/Mark III, Sega Genesis/Mega Drive,BBC Micro

%package -n libgme%{soname}
Summary:        Collection of video game music file emulators
Group:          System/Libraries

%description -n libgme%{soname}
Game_Music_Emu is a collection of video game music file emulators that support
the following formats and systems:
- AY: ZX Spectrum/Amstrad CPC
- GBS: Nintendo Game Boy
- GYM: Sega Genesis/Mega Drive
- HES: NEC TurboGrafx-16/PC Engine
- KSS: MSX Home Computer/other Z80 systems (doesn't support FM sound)
- NSF/NSFE: Nintendo NES/Famicom (with VRC 6, Namco 106, and FME-7 sound)
- SAP: Atari systems using POKEY sound chip
- SPC: Super Nintendo/Super Famicom
- VGM/VGZ: Sega Master System/Mark III, Sega Genesis/Mega Drive,BBC Micro

%package devel
Summary:        Development libraries and headers for libgme
Group:          Development/Libraries/C and C++
Requires:       libgme%{soname} = %{version}

%description devel
The developmental files that must be installed in order to compile applications
which use libgme.

%prep
%setup -q -n game-music-emu-%{version}
sed -i 's/\r$//' changes.txt design.txt gme.txt license.txt readme.txt

%build
%cmake
%make_build

%install
%cmake_install

%post -n libgme%{soname} -p /sbin/ldconfig
%postun -n libgme%{soname} -p /sbin/ldconfig

%files -n libgme%{soname}
%license license.txt
%doc changes.txt gme.txt readme.txt
%{_libdir}/libgme.so.%{soname}*

%files devel
%doc design.txt
%{_includedir}/gme
%{_libdir}/libgme.so
%{_libdir}/pkgconfig/libgme.pc

%changelog
* Wed Jun 15 2022 Callum Farmer <gmbr3@opensuse.org>
- Remove bad %%defattr - not needed and causes SHLIB non-executable
  rpmlint error
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * includes a couple of years' worth of feature changes and bugfixes.
- drop fix-gcc10-compiler-detection.patch (upstream)
* Tue Dec  3 2019 Martin Liška <mliska@suse.cz>
- Add fix-gcc10-compiler-detection.patch in order
  to fix boo#1158320.
* Sat Jan 20 2018 tom.mbrt@googlemail.com
- Update to 0.6.2:
  * fix crashes in nsfe emulator
* Sat Jun 10 2017 tom.mbrt@googlemail.com
- Update to 0.6.1:
  * "libgme-0.6.0-pkgconfig_path.patch" and "cve-2016-9957.patch"
    got fixed upstream
  * Following functions added to API:
  - gme_tell_samples();
  - gme_seek_samples();
* Fri Dec 16 2016 psimons@suse.com
- Apply "cve-2016-9957.patch" to fix an arbitrary code execution
  vulnerability that could have been exploited using specially
  crafted SPC music files. [CVE-2016-9957, CVE-2016-9958,
  CVE-2016-9959, CVE-2016-9960, CVE-2016-9961, bsc#1015941]
* Wed Dec 23 2015 mpluskal@suse.com
- Mention baselibs.conf as source
- Use cmake macros
- Cleanup spec file with spec-cleaner
- Update project url and download location
* Wed Dec 16 2015 olaf@aepfle.de
- Add BuildRoot: for SLE_11
* Sun Mar 17 2013 reddwarf@opensuse.org
- Update to 0.6.0
  * SPC improvements:
  - Switched to newer snes_spc 0.9.0 for SPC emulation. Uses fast DSP.
  - Fixed Spc_Emu::gain().
  - Fixed support for files <0x10200 bytes.
  * Other bugfixes:
  - Fixed a couple of GBS bugs, one involving access of memory after
    realloc.
  - Blip_Buffer works on systems where 'double' is a single-precision
    floating-point type.
  - Fix uninitialized buffer size in dual_resampler.
  - Compilation warnings squashed out as of clang 3.3-pre and gcc 4.7.2.
  * API changes/additions:
  - Removed documentation of C++ interface, as the C interface in gme.h is
    the only supported one.
  - Added gme_enable_accuracy() for enabling more accurate sound emulation
    options (currently affects SPC only).
  * Build system improvements:
  - Add pkg_config support.
  - Fix build on case-insensitive systems.
  - Allow for install on Cygwin.
  - Fix install on multilib systems, such as many 64-bit distros (CMake must
    be able to figure out your system's libsuffix, if any).
  - C++ implementation symbols are not leaked into the resultant library
    file (requires symbol visibility support).
  * Sample player improvements:
  - Can toggle fast/accurate emulation (with the 'A' key).
- Remove all the previous patches (libgme-0.5.5-LIB_SUFFIX.patch,
  libgme-0.5.5-pkg_config.patch and libgme-0.5.5-symbol_visibility.patch)
- Add libgme-0.6.0-pkgconfig_path.patch
* Tue May  3 2011 reddwarf@opensuse.org
- Update libgme-0.5.5-symbol_visibility.patch to not install
  headers for functions that are not exported.
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Escaped macros in comments (fix for RPMLINT warning)
* Tue Dec 14 2010 reddwarf@opensuse.org
- Initial package
